<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>PianoPalette</name>
    <message>
        <location filename="../pianopalette.cpp" line="143"/>
        <location filename="../pianopalette.cpp" line="215"/>
        <location filename="../pianopalette.cpp" line="226"/>
        <location filename="../pianopalette.cpp" line="297"/>
        <location filename="../pianopalette.cpp" line="354"/>
        <location filename="../pianopalette.cpp" line="365"/>
        <source>N</source>
        <translation>N</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="144"/>
        <location filename="../pianopalette.cpp" line="216"/>
        <location filename="../pianopalette.cpp" line="227"/>
        <location filename="../pianopalette.cpp" line="298"/>
        <location filename="../pianopalette.cpp" line="355"/>
        <location filename="../pianopalette.cpp" line="366"/>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="154"/>
        <location filename="../pianopalette.cpp" line="308"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="155"/>
        <location filename="../pianopalette.cpp" line="309"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="156"/>
        <location filename="../pianopalette.cpp" line="310"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="157"/>
        <location filename="../pianopalette.cpp" line="311"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="158"/>
        <location filename="../pianopalette.cpp" line="312"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="159"/>
        <location filename="../pianopalette.cpp" line="313"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="160"/>
        <location filename="../pianopalette.cpp" line="314"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="161"/>
        <location filename="../pianopalette.cpp" line="315"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="162"/>
        <location filename="../pianopalette.cpp" line="316"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="163"/>
        <location filename="../pianopalette.cpp" line="317"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="164"/>
        <location filename="../pianopalette.cpp" line="318"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="165"/>
        <location filename="../pianopalette.cpp" line="319"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="166"/>
        <location filename="../pianopalette.cpp" line="320"/>
        <source>13</source>
        <translation>13</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="167"/>
        <location filename="../pianopalette.cpp" line="321"/>
        <source>14</source>
        <translation>14</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="168"/>
        <location filename="../pianopalette.cpp" line="322"/>
        <source>15</source>
        <translation>15</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="169"/>
        <location filename="../pianopalette.cpp" line="323"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="194"/>
        <location filename="../pianopalette.cpp" line="333"/>
        <source>C</source>
        <translation>До</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="195"/>
        <location filename="../pianopalette.cpp" line="334"/>
        <source>C#</source>
        <translation>До #</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="196"/>
        <location filename="../pianopalette.cpp" line="335"/>
        <source>D</source>
        <translation>Ре</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="197"/>
        <location filename="../pianopalette.cpp" line="336"/>
        <source>D#</source>
        <translation>Ре #</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="198"/>
        <location filename="../pianopalette.cpp" line="337"/>
        <source>E</source>
        <translation>Ми</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="199"/>
        <location filename="../pianopalette.cpp" line="338"/>
        <source>F</source>
        <translation>Фа</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="200"/>
        <location filename="../pianopalette.cpp" line="339"/>
        <source>F#</source>
        <translation>Фа #</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="201"/>
        <location filename="../pianopalette.cpp" line="340"/>
        <source>G</source>
        <translation>Соль</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="202"/>
        <location filename="../pianopalette.cpp" line="341"/>
        <source>G#</source>
        <translation>Соль #</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="203"/>
        <location filename="../pianopalette.cpp" line="342"/>
        <source>A</source>
        <translation>Ля</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="204"/>
        <location filename="../pianopalette.cpp" line="343"/>
        <source>A#</source>
        <translation>Ля #</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="205"/>
        <location filename="../pianopalette.cpp" line="344"/>
        <source>B</source>
        <translation>Си</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="228"/>
        <location filename="../pianopalette.cpp" line="367"/>
        <source>N*</source>
        <translation>N*</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="229"/>
        <location filename="../pianopalette.cpp" line="368"/>
        <source>#*</source>
        <translation>#*</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="241"/>
        <source>Single color highlight</source>
        <translation>Подсветка одним цветом</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="242"/>
        <source>A single color to highlight all note events</source>
        <translation>Один цвет для подсветки всех событий нот</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="246"/>
        <source>Two colors highlight</source>
        <translation>Подсветка двумя цветами</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="247"/>
        <source>One color to highlight natural notes and a different one for accidentals</source>
        <translation>Один цвет подсвечивает натуральные ноты, второй акцентированные</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="251"/>
        <source>MIDI Channels highlight</source>
        <translation>Подсветка каналов MIDI</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="252"/>
        <source>A different color to highlight each MIDI channel. Enable Omni mode in the MIDI IN connection</source>
        <translation>Разные цвета подсветки каждого канала MIDI. Включить режим Omni в соединении MIDI IN</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="256"/>
        <source>Chromatic scale background</source>
        <translation>Хроматический фон</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="257"/>
        <location filename="../pianopalette.cpp" line="272"/>
        <source>One color for each note in the chromatic scale</source>
        <translation>Один цвет для каждой ноты по хроматической шкале</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="261"/>
        <source>Keys background</source>
        <translation>Фон клавиш</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="262"/>
        <source>One color for natural notes and another for accidentals</source>
        <translation>Один цвет для натуральных нот и один для акцентированных</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="266"/>
        <source>Font foreground</source>
        <translation>Цвет шрифта</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="267"/>
        <source>Colors for note names</source>
        <translation>Цвета для названий нот</translation>
    </message>
    <message>
        <location filename="../pianopalette.cpp" line="271"/>
        <source>Chromatic scale highlight</source>
        <translation>Подсветка хроматической шкалой</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::FluidSettingsDialog</name>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="14"/>
        <source>FluidSynth Driver Settings</source>
        <translation>Настройки драйвера FluidSynth</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="123"/>
        <source>Sample Rate:</source>
        <translation>Скорость сэмплов:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="106"/>
        <source>Period Size:</source>
        <translation>Размер периода:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="159"/>
        <source># of Periods:</source>
        <translation>Число периодов:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="39"/>
        <source>Audio Driver:</source>
        <translation>Аудиодрайвер:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="169"/>
        <source>Polyphony:</source>
        <translation>Полифония:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="89"/>
        <source>FluidSynth Version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="69"/>
        <source>Sound Font:</source>
        <translation>Sound Font:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="116"/>
        <source>Initialization Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="185"/>
        <source>Buffer Time:</source>
        <translation type="unfinished">Время буфера:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="192"/>
        <source> ms</source>
        <translation type="unfinished"> мс</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="49"/>
        <source>Gain:</source>
        <translation>Усиление:</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="152"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="139"/>
        <source>Chorus</source>
        <translation>Хорус</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.ui" line="62"/>
        <source>Reverb</source>
        <translation>Реверберация</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="140"/>
        <source>FluidSynth Initialized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="140"/>
        <source>FluidSynth Initialization Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="206"/>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="206"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="334"/>
        <source>Select SoundFont</source>
        <translation>Выбрать SoundFont</translation>
    </message>
    <message>
        <location filename="../fluidsettingsdialog.cpp" line="334"/>
        <source>SoundFont Files (*.sf2 *.sf3 *.dls)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SoundFont Files (*.sf2)</source>
        <translation type="vanished">Файлы SoundFont (*.sf2)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::MacSynthSettingsDialog</name>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="14"/>
        <source>macOS Synth Driver Settings</source>
        <translation>Настройки драйвера macOS Synth</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="56"/>
        <source>SoundFont:</source>
        <translation>SoundFont:</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="76"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="83"/>
        <source>Use Internal Reverb</source>
        <translation>Использовать встроенную реверберацию</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="90"/>
        <source>Init. Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.ui" line="69"/>
        <source>Default Apple DLS Sound Set</source>
        <translation>Набор звуков Apple DLS по умолчанию</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="72"/>
        <source>DLS Synth Initialization Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="122"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>Select SoundFont</source>
        <translation>Выбор SoundFont</translation>
    </message>
    <message>
        <location filename="../macsynthsettingsdialog.cpp" line="163"/>
        <source>SoundFont Files (*.sf2 *.dls)</source>
        <translation>Файлы SoundFont (*.sf2 *.dls)</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::NetworkSettingsDialog</name>
    <message>
        <location filename="../networksettingsdialog.ui" line="14"/>
        <source>Network Driver Settings</source>
        <translation>Настройки драйвера сети</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="33"/>
        <source>Init. Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="50"/>
        <source>Use IPv6</source>
        <translation>Использовать IPv6</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="57"/>
        <source>Network Interface:</source>
        <translation>Сетевой интерфейс:</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.ui" line="70"/>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="76"/>
        <source>Network Initialization Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="111"/>
        <location filename="../networksettingsdialog.cpp" line="174"/>
        <source>Any</source>
        <translation>Любой</translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../networksettingsdialog.cpp" line="164"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::PianoScene</name>
    <message>
        <location filename="../pianoscene.cpp" line="1301"/>
        <location filename="../pianoscene.cpp" line="1314"/>
        <source>C</source>
        <translation>До</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1302"/>
        <source>C♯</source>
        <translation>До♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1303"/>
        <location filename="../pianoscene.cpp" line="1316"/>
        <source>D</source>
        <translation>Ре</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1304"/>
        <source>D♯</source>
        <translation>Ре♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1305"/>
        <location filename="../pianoscene.cpp" line="1318"/>
        <source>E</source>
        <translation>Ми</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1306"/>
        <location filename="../pianoscene.cpp" line="1319"/>
        <source>F</source>
        <translation>Фа</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1307"/>
        <source>F♯</source>
        <translation>Фа♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1308"/>
        <location filename="../pianoscene.cpp" line="1321"/>
        <source>G</source>
        <translation>Соль</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1309"/>
        <source>G♯</source>
        <translation>Соль♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1310"/>
        <location filename="../pianoscene.cpp" line="1323"/>
        <source>A</source>
        <translation>Ля</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1311"/>
        <source>A♯</source>
        <translation>Ля♯</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1312"/>
        <location filename="../pianoscene.cpp" line="1325"/>
        <source>B</source>
        <translation>Си</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1315"/>
        <source>D♭</source>
        <translation>Ре♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1317"/>
        <source>E♭</source>
        <translation>Ми♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1320"/>
        <source>G♭</source>
        <translation>Соль♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1322"/>
        <source>A♭</source>
        <translation>Ля♭</translation>
    </message>
    <message>
        <location filename="../pianoscene.cpp" line="1324"/>
        <source>B♭</source>
        <translation>Си♭</translation>
    </message>
</context>
<context>
    <name>drumstick::widgets::SonivoxSettingsDialog</name>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="14"/>
        <source>Sonivox EAS Synth</source>
        <translation>Sonivox EAS Synth</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="26"/>
        <source>Chorus</source>
        <translation>Хорус</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="43"/>
        <source>Reverb</source>
        <translation>Реверберация</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="71"/>
        <source>Buffer Time:</source>
        <translation>Время буфера:</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="81"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.ui" line="110"/>
        <source>Init. Status:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="85"/>
        <source>Sonivox Initialized</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="85"/>
        <source>Sonivox Initialization Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="165"/>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../sonivoxsettingsdialog.cpp" line="165"/>
        <source>Failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
